PrefetchPolicy

Enum PrefetchPolicy 

pub enum PrefetchPolicy {
    None,
    Fs,
    Blob,
}
Filesystem data prefetch policy.

Variants



None



Fs

Prefetch will be issued from Fs layer, which leverages inode/chunkinfo to prefetch data from blob no matter where it resides(OSS/Localfs). Basically, it is willing to cache the data into blobcache(if exists). It’s more nimble. With this policy applied, image builder currently puts prefetch files’ data into a continuous region within blob which behaves very similar to Blob policy.



Blob

Prefetch will be issued directly from backend/blob layer