pub struct ArtifactWriter { /* private fields */ }Expand description
ArtifactWriter provides a writer to allow writing bootstrap or blob data to a single file or in a directory.
Implementations
Sourceimpl ArtifactWriter
impl ArtifactWriter
Sourcepub fn new(storage: ArtifactStorage) -> Result<Self>
pub fn new(storage: ArtifactStorage) -> Result<Self>
Create a new instance of ArtifactWriter from a ArtifactStorage configuration object.