BuildContext

Struct BuildContext 

pub struct BuildContext {
Show 28 fields pub blob_id: String, pub aligned_chunk: bool, pub blob_offset: u64, pub compressor: Algorithm, pub digester: Algorithm, pub cipher: Algorithm, pub crc32_algorithm: Algorithm, pub explicit_uidgid: bool, pub whiteout_spec: WhiteoutSpec, pub chunk_size: u32, pub batch_size: u32, pub fs_version: RafsVersion, pub has_xattr: bool, pub conversion_type: ConversionType, pub source_path: PathBuf, pub prefetch: Prefetch, pub blob_storage: Option<ArtifactStorage>, pub external_blob_storage: Option<ArtifactStorage>, pub blob_zran_generator: Option<Mutex<ZranContextGenerator<File>>>, pub blob_batch_generator: Option<Mutex<BatchContextGenerator>>, pub blob_tar_reader: Option<BufReaderInfo<File>>, pub blob_features: BlobFeatures, pub blob_inline_meta: bool, pub features: Features, pub configuration: Arc<ConfigV2>, pub blob_cache_generator: Option<BlobCacheGenerator>, pub is_chunkdict_generated: bool, pub attributes: Attributes,
}

Fields

blob_id: String

Blob id (user specified or sha256(blob)).

aligned_chunk: bool

When filling local blobcache file, chunks are arranged as per the decompress_offset within chunk info. Therefore, provide a new flag to image tool thus to align chunks in blob with 4k size.

blob_offset: u64

Add a offset for compressed blob.

compressor: Algorithm

Blob chunk compress flag.

digester: Algorithm

Inode and chunk digest algorithm flag.

cipher: Algorithm

Blob encryption algorithm flag.

crc32_algorithm: Algorithmexplicit_uidgid: bool

Save host uid gid in each inode.

whiteout_spec: WhiteoutSpec

whiteout spec: overlayfs or oci

chunk_size: u32

Chunk slice size.

batch_size: u32

Batch chunk data size.

fs_version: RafsVersion

Version number of output metadata and data blob.

has_xattr: bool

Whether any directory/file has extended attributes.

conversion_type: ConversionType

Format conversion type.

source_path: PathBuf

Path of source to build the image from:

  • Directory: source_path should be a directory path
  • StargzIndex: source_path should be a stargz index json file path
prefetch: Prefetch

Track file/chunk prefetch state.

blob_storage: Option<ArtifactStorage>

Storage writing blob to single file or a directory.

external_blob_storage: Option<ArtifactStorage>blob_zran_generator: Option<Mutex<ZranContextGenerator<File>>>blob_batch_generator: Option<Mutex<BatchContextGenerator>>blob_tar_reader: Option<BufReaderInfo<File>>blob_features: BlobFeaturesblob_inline_meta: boolfeatures: Featuresconfiguration: Arc<ConfigV2>blob_cache_generator: Option<BlobCacheGenerator>

Generate the blob cache and blob meta

is_chunkdict_generated: bool

Whether is chunkdict.

attributes: Attributes

Nydus attributes for different build behavior.

Implementations

Source

impl BuildContext

pub fn new( blob_id: String, aligned_chunk: bool, blob_offset: u64, compressor: Algorithm, digester: Algorithm, explicit_uidgid: bool, whiteout_spec: WhiteoutSpec, conversion_type: ConversionType, source_path: PathBuf, prefetch: Prefetch, blob_storage: Option<ArtifactStorage>, external_blob_storage: Option<ArtifactStorage>, blob_inline_meta: bool, features: Features, encrypt: bool, attributes: Attributes, ) -> Self

pub fn set_fs_version(&mut self, fs_version: RafsVersion)

pub fn set_chunk_size(&mut self, chunk_size: u32)

pub fn set_batch_size(&mut self, batch_size: u32)

pub fn set_configuration(&mut self, config: Arc<ConfigV2>)

pub fn set_is_chunkdict(&mut self, is_chunkdict: bool)

Source

impl BuildContext

pub fn v6_block_size(&self) -> u64

pub fn v6_block_addr(&self, offset: u64) -> Result<u32>