pub struct Merger {}Expand description
Struct to generate the merged RAFS bootstrap for an image from per layer RAFS bootstraps.
A container image contains one or more layers, a RAFS bootstrap is built for each layer. Those per layer bootstraps could be mounted by overlayfs to form the container rootfs. To improve performance by avoiding overlayfs, an image level bootstrap is generated by merging per layer bootstrap with overlayfs rules applied.
Implementations
Sourceimpl Merger
impl Merger
Sourcepub fn merge(
ctx: &mut BuildContext,
parent_bootstrap_path: Option<String>,
sources: Vec<PathBuf>,
blob_digests: Option<Vec<String>>,
original_blob_ids: Option<Vec<String>>,
blob_sizes: Option<Vec<u64>>,
blob_toc_digests: Option<Vec<String>>,
blob_toc_sizes: Option<Vec<u64>>,
target: ArtifactStorage,
chunk_dict: Option<PathBuf>,
config_v2: Arc<ConfigV2>,
) -> Result<BuildOutput>
pub fn merge( ctx: &mut BuildContext, parent_bootstrap_path: Option<String>, sources: Vec<PathBuf>, blob_digests: Option<Vec<String>>, original_blob_ids: Option<Vec<String>>, blob_sizes: Option<Vec<u64>>, blob_toc_digests: Option<Vec<String>>, blob_toc_sizes: Option<Vec<u64>>, target: ArtifactStorage, chunk_dict: Option<PathBuf>, config_v2: Arc<ConfigV2>, ) -> Result<BuildOutput>
Overlay multiple RAFS filesystems into a merged RAFS filesystem.
Arguments
- sources: contains one or more per layer bootstraps in order of lower to higher.
- chunk_dict: contain the chunk dictionary used to build per layer boostrap, or None.