Tree

Struct Tree 

pub struct Tree {
    pub node: TreeNode,
    pub children: Vec<Tree>,
    /* private fields */
}
An in-memory tree structure to maintain information and topology of filesystem nodes.

Fields

node: TreeNode

Filesystem node.

children: Vec<Tree>

Children tree nodes.

Implementations

Source

impl Tree

pub fn new(node: Node) -> Self

Create a new instance of Tree from a filesystem node.

pub fn from_bootstrap<T: ChunkDict>( rs: &RafsSuper, chunk_dict: &mut T, ) -> Result<Self>

Load a Tree from a bootstrap file, and optionally caches chunk information.

pub fn name(&self) -> &[u8]

Get name of the tree node.

pub fn set_node(&mut self, node: Node)

Set Node associated with the tree node.

pub fn borrow_mut_node(&self) -> RefMut<'_, Node>

Get mutably borrowed value to access the associated Node object.

pub fn walk_dfs<F1, F2>(&self, pre: &mut F1, post: &mut F2) -> Result<()>
where F1: FnMut(&Tree) -> Result<()>, F2: FnMut(&Tree) -> Result<()>,

Walk all nodes in DFS mode.

pub fn walk_dfs_pre<F>(&self, cb: &mut F) -> Result<()>
where F: FnMut(&Tree) -> Result<()>,

Walk all nodes in pre DFS mode.

pub fn walk_dfs_post<F>(&self, cb: &mut F) -> Result<()>
where F: FnMut(&Tree) -> Result<()>,

Walk all nodes in post DFS mode.

pub fn walk_bfs<F>(&self, handle_self: bool, cb: &mut F) -> Result<()>
where F: FnMut(&Tree) -> Result<()>,

Walk the tree in BFS mode.

pub fn insert_child(&mut self, child: Tree)

Insert a new child node into the tree.

pub fn get_child_idx(&self, name: &[u8]) -> Option<usize>

Get index of child node with specified name.

pub fn get_node(&self, path: &Path) -> Option<&Tree>

Get the tree node corresponding to the path.

pub fn get_node_mut(&mut self, path: &Path) -> Option<&mut Tree>

Get the mutable tree node corresponding to the path.

pub fn merge_overaly(&mut self, ctx: &BuildContext, upper: Tree) -> Result<()>

Merge the upper layer tree into the lower layer tree, applying whiteout rules.