pub struct BuildContext {Show 28 fields
pub blob_id: String,
pub aligned_chunk: bool,
pub blob_offset: u64,
pub compressor: Algorithm,
pub digester: Algorithm,
pub cipher: Algorithm,
pub crc32_algorithm: Algorithm,
pub explicit_uidgid: bool,
pub whiteout_spec: WhiteoutSpec,
pub chunk_size: u32,
pub batch_size: u32,
pub fs_version: RafsVersion,
pub has_xattr: bool,
pub conversion_type: ConversionType,
pub source_path: PathBuf,
pub prefetch: Prefetch,
pub blob_storage: Option<ArtifactStorage>,
pub external_blob_storage: Option<ArtifactStorage>,
pub blob_zran_generator: Option<Mutex<ZranContextGenerator<File>>>,
pub blob_batch_generator: Option<Mutex<BatchContextGenerator>>,
pub blob_tar_reader: Option<BufReaderInfo<File>>,
pub blob_features: BlobFeatures,
pub blob_inline_meta: bool,
pub features: Features,
pub configuration: Arc<ConfigV2>,
pub blob_cache_generator: Option<BlobCacheGenerator>,
pub is_chunkdict_generated: bool,
pub attributes: Attributes,
}Fields
blob_id: StringBlob id (user specified or sha256(blob)).
aligned_chunk: boolWhen filling local blobcache file, chunks are arranged as per the
decompress_offset within chunk info. Therefore, provide a new flag
to image tool thus to align chunks in blob with 4k size.
blob_offset: u64Add a offset for compressed blob.
compressor: AlgorithmBlob chunk compress flag.
digester: AlgorithmInode and chunk digest algorithm flag.
cipher: AlgorithmBlob encryption algorithm flag.
crc32_algorithm: Algorithmexplicit_uidgid: boolSave host uid gid in each inode.
whiteout_spec: WhiteoutSpecwhiteout spec: overlayfs or oci
chunk_size: u32Chunk slice size.
batch_size: u32Batch chunk data size.
fs_version: RafsVersionVersion number of output metadata and data blob.
has_xattr: boolWhether any directory/file has extended attributes.
conversion_type: ConversionTypeFormat conversion type.
source_path: PathBufPath of source to build the image from:
- Directory:
source_pathshould be a directory path - StargzIndex:
source_pathshould be a stargz index json file path
prefetch: PrefetchTrack file/chunk prefetch state.
blob_storage: Option<ArtifactStorage>Storage writing blob to single file or a directory.
external_blob_storage: Option<ArtifactStorage>blob_zran_generator: Option<Mutex<ZranContextGenerator<File>>>blob_batch_generator: Option<Mutex<BatchContextGenerator>>blob_tar_reader: Option<BufReaderInfo<File>>blob_features: BlobFeaturesblob_inline_meta: boolfeatures: Featuresconfiguration: Arc<ConfigV2>blob_cache_generator: Option<BlobCacheGenerator>Generate the blob cache and blob meta
is_chunkdict_generated: boolWhether is chunkdict.
attributes: AttributesNydus attributes for different build behavior.