pub struct CompactConfig {
pub min_used_ratio: u8,
pub compact_blob_size: usize,
pub max_compact_size: usize,
pub layers_to_compact: usize,
pub blobs_dir: String,
}Fields
min_used_ratio: u8rebuild blobs whose used_ratio < min_used_ratio used_ratio = (compress_size of all chunks which are referenced by bootstrap) / blob_compress_size available value: 0-99, 0 means disable hint: it’s better to disable this option when there are some shared blobs for example: build-cache
compact_blob_size: usizewe compact blobs whose size are less than compact_blob_size
max_compact_size: usizesize of compacted blobs should not be larger than max_compact_size
layers_to_compact: usizeif number of blobs >= layers_to_compact, do compact 0 means always try compact
blobs_dir: Stringlocal blobs dir, may haven’t upload to backend yet what’s more, new blobs will output to this dir name of blob file should be equal to blob_id